/* This file is part of the KDE project
   Copyright (C) 2004 Alexander Dymo <adymo@kdevelop.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/
#ifndef KDEVPLUGINCONTROLLER_H
#define KDEVPLUGINCONTROLLER_H

#include <ktrader.h>

/**
@file kdevplugincontroller.h
KDevelop plugin controller interface.
*/

/**
The base class for KDevelop plugin controller.
Plugin controller is responsible for quering, loading and unloading available plugins.
*/
class KDevPluginController
{
public:
    /**Queries KDevelop services. Version is checked automatically
    by adding proper X-KDevelop-Version=N statement into the query.
    @param serviceType The service type to query, for example "KDevelop/Plugin" or
    "KDevelop/SourceFormatter."
    @param constraint A constraint for the service. Do not include plugin version number - it
    is done automatically.
    @return The list of plugin offers.*/
    static KTrader::OfferList query(const QString &serviceType, const QString &constraint);
    /**Queries KDevelop plugins. Works like
    KDevPluginController::query with serviceType set to "KDevelop/Plugin".
    @param constraint A constraint for the service. Do not include plugin version number - it
    is done automatically.
    @return The list of plugin offers.*/
    static KTrader::OfferList queryPlugins(const QString &constraint);

protected:
    KDevPluginController();

};

#endif
